@@ -30,11 +30,11 @@ data(sbp)
 data(psub)
 
 cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+                parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 
 suppressWarnings(
   m <- brmcoda(compilr = cilr,
-               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
                  wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
                chain = 1, iter = 500, seed = 123,
                backend = backend))
@@ -54,7 +54,7 @@ x <- bsub(object = m, basesub = psub, delta = 2)
 #   expect_error(x <- bsub(object = m, delta = 2))
 # 
 #   ## not brmcoda model
-#   m1 <- lmer(STRESS ~ 1 + (1 | ID), data = mcompd)
+#   m1 <- lmer(Stress ~ 1 + (1 | ID), data = mcompd)
 #   expect_error(x <- bsub(object = m1, basesub = psub, delta = 2))
 # 
 #   ## invalid delta
@@ -80,7 +80,7 @@ x <- bsub(object = m, basesub = psub, delta = 2)
 #   ## reference grid is provided for unadjusted model
 #   suppressWarnings(
 #     m2 <- brmcoda(compilr = cilr,
-#                   formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                   formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                     wilr1 + wilr2 + wilr3 + wilr4 + (1 | ID),
 #                   chain = 1, iter = 500, seed = 123,
 #                   backend = "cmdstanr"))
@@ -138,11 +138,11 @@ x <- bsub(object = m, basesub = psub, delta = 2)
 #   
 #   ## keep prediction at each level of refrence grid 
 #   cilr <- compilr(data = mcompd[ID %in% c(1:5, 185:190), .SD[1:3], by = ID], sbp = sbp,
-#                   parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                   parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 #   
 #   suppressWarnings(
 #     m <- brmcoda(compilr = cilr,
-#                  formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                  formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                    wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                  chain = 1, iter = 500, seed = 123,
 #                  backend = "cmdstanr"))
@@ -305,11 +305,11 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
   
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "WAKE"), idvar = "ID")
+                  parts = c("TST", "WAKE"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "WAKE"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   a <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -336,11 +336,11 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
   
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "MVPA"), idvar = "ID")
+                  parts = c("TST", "MVPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "MVPA"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   b <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -367,11 +367,11 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "LPA"), idvar = "ID")
+                  parts = c("TST", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "LPA"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   c <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -398,11 +398,11 @@ test_that("bsub's results matches with brm model for 2-component composition (TS
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "SB"), idvar = "ID")
+                  parts = c("TST", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   d <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -429,12 +429,12 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("WAKE", "MVPA"), idvar = "ID")
+                  parts = c("WAKE", "MVPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "MVPA"))
   
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   e <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -461,11 +461,11 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("WAKE", "LPA"), idvar = "ID")
+                  parts = c("WAKE", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "LPA"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   f <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -492,11 +492,11 @@ test_that("bsub's results matches with brm model for 2-component composition (WA
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("WAKE", "SB"), idvar = "ID")
+                  parts = c("WAKE", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   g <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -523,10 +523,10 @@ test_that("bsub's results matches with brm model for 2-component composition (MV
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("MVPA", "LPA"), idvar = "ID")
+                  parts = c("MVPA", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("MVPA", "LPA"))
   suppressWarnings(m <- brmcoda(compilr = cilr,
-                                formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                                formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                                 chain = 1, iter = 500, seed = 123,
                                 backend = "cmdstanr"))
   h <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -553,11 +553,11 @@ test_that("bsub's results matches with brm model for 2-component composition (MV
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("MVPA", "SB"), idvar = "ID")
+                  parts = c("MVPA", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("MVPA", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   i <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -584,11 +584,11 @@ test_that("bsub's results matches with brm model for 2-component composition (LP
 
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("LPA", "SB"), idvar = "ID")
+                  parts = c("LPA", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("LPA", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = "cmdstanr"))
   j <- bsub(object = m, basesub = psub, delta = 1:2)
@@ -623,10 +623,10 @@ test_that("bsub's results matches with brm model for 2-component composition (LP
 # # model as usual
 # data("sbp")
 # cilr <- compilr(data = mcompd, sbp = sbp,
-#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
 # suppressWarnings(m <- brmcoda(compilr = cilr,
-#                               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               chain = 10, iter = 10000, cores = 8, seed = 123))
 # 
@@ -639,10 +639,10 @@ test_that("bsub's results matches with brm model for 2-component composition (LP
 #   0, 1, -1, 0, 0), ncol = 5, byrow = TRUE)
 # 
 # cilr <- compilr(data = mcompd, sbp = sbp,
-#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
 # suppressWarnings(m <- brmcoda(compilr = cilr,
-#                               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               chain = 10, iter = 10000, cores = 8, seed = 123))
 # 
