@@ -26,11 +26,11 @@ data(sbp)
 data(psub)
 
 cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+                parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 
 suppressWarnings(
   m <- brmcoda(compilr = cilr,
-               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
                  wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
                chain = 1, iter = 500, seed = 123,
                backend = backend))
@@ -50,7 +50,7 @@ x <- wsub(object = m, basesub = psub, delta = 2)
 #   expect_error(x <- wsub(object = m, delta = 2))
 # 
 #   ## not brmcoda model
-#   m1 <- lmer(STRESS ~ 1 + (1 | ID), data = mcompd)
+#   m1 <- lmer(Stress ~ 1 + (1 | ID), data = mcompd)
 #   expect_error(x <- wsub(object = m1, basesub = psub, delta = 2))
 # 
 #   ## invalid delta
@@ -75,7 +75,7 @@ x <- wsub(object = m, basesub = psub, delta = 2)
 #   ## reference grid is provided for unadjusted model
 #   suppressWarnings(
 #     m2 <- brmcoda(compilr = cilr,
-#                   formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                   formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                     wilr1 + wilr2 + wilr3 + wilr4 + (1 | ID),
 #                   chain = 1, iter = 500, seed = 123,
 #                   backend = backend))
@@ -133,11 +133,11 @@ x <- wsub(object = m, basesub = psub, delta = 2)
 #   
 #   ## keep prediction at each level of refrence grid 
 #   cilr <- compilr(data = mcompd[ID %in% c(1:5, 185:190), .SD[1:3], by = ID], sbp = sbp,
-#                   parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                   parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 #   
 #   suppressWarnings(
 #     m <- brmcoda(compilr = cilr,
-#                  formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                  formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                    wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                  chain = 1, iter = 500, seed = 123,
 #                  backend = backend))
@@ -305,10 +305,10 @@ test_that("wsub gives results in expected direction and magnitude", {
 #   0, 0, 1, -1, 0), ncol = 5, byrow = TRUE)
 # 
 # cilr <- compilr(data = mcompd, sbp = sbp,
-#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
 # suppressWarnings(m <- brmcoda(compilr = cilr,
-#                               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               seed = 123))
 # 
@@ -355,10 +355,10 @@ test_that("wsub gives results in expected direction and magnitude", {
 #   0, 0, 0, 1, -1), ncol = 5, byrow = TRUE)
 # 
 # cilr <- compilr(data = mcompd, sbp = sbp,
-#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
 # suppressWarnings(m <- brmcoda(compilr = cilr,
-#                               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               seed = 123))
 # 
@@ -403,10 +403,10 @@ test_that("wsub gives results in expected direction and magnitude", {
 #   0, 1, 0, 0, -1), ncol = 5, byrow = TRUE)
 # 
 # cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
 # suppressWarnings(m <- brmcoda(compilr = cilr,
-#                               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               chain = 1, iter = 500, seed = 123))
 # 
@@ -451,10 +451,10 @@ test_that("wsub gives results in expected direction and magnitude", {
 #   0, 1, -1, 0, 0), ncol = 5, byrow = TRUE)
 # 
 # cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
 # suppressWarnings(m <- brmcoda(compilr = cilr,
-#                               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               chain = 1, iter = 500, seed = 123))
 # 
@@ -499,10 +499,10 @@ test_that("wsub gives results in expected direction and magnitude", {
 #   0, 1, 0, -1, 0), ncol = 5, byrow = TRUE)
 # 
 # cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID")
+#                 parts = c("TST", "WAKE", "MVPA", "LPA", "SB"), idvar = "ID", total = 1440)
 # 
 # suppressWarnings(m <- brmcoda(compilr = cilr,
-#                               formula = STRESS ~ bilr1 + bilr2 + bilr3 + bilr4 +
+#                               formula = Stress ~ bilr1 + bilr2 + bilr3 + bilr4 +
 #                                 wilr1 + wilr2 + wilr3 + wilr4 + Female + (1 | ID),
 #                               seed = 123))
 # 
@@ -547,11 +547,11 @@ test_that("wsub's results matches with brm model for 2-component composition (TS
   
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "WAKE"), idvar = "ID")
+                  parts = c("TST", "WAKE"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "WAKE"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   a <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -578,11 +578,11 @@ test_that("wsub's results matches with brm model for 2-component composition (TS
   
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "MVPA"), idvar = "ID")
+                  parts = c("TST", "MVPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "MVPA"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   b <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -608,11 +608,11 @@ test_that("wsub's results matches with brm model for 2-component composition (TS
 test_that("wsub's results matches with brm model for 2-component composition (TST vs LPA)", {
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "LPA"), idvar = "ID")
+                  parts = c("TST", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "LPA"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   c <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -638,11 +638,11 @@ test_that("wsub's results matches with brm model for 2-component composition (TS
 test_that("wsub's results matches with brm model for 2-component composition (TST vs SB)", {
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("TST", "SB"), idvar = "ID")
+                  parts = c("TST", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("TST", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   d <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -668,12 +668,12 @@ test_that("wsub's results matches with brm model for 2-component composition (TS
 test_that("wsub's results matches with brm model for 2-component composition (WAKE vs MVPA)", {
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("WAKE", "MVPA"), idvar = "ID")
+                  parts = c("WAKE", "MVPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "MVPA"))
   
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   e <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -699,11 +699,11 @@ test_that("wsub's results matches with brm model for 2-component composition (WA
 test_that("wsub's results matches with brm model for 2-component composition (WAKE vs LPA)", {
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("WAKE", "LPA"), idvar = "ID")
+                  parts = c("WAKE", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "LPA"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   f <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -729,11 +729,11 @@ test_that("wsub's results matches with brm model for 2-component composition (WA
 test_that("wsub's results matches with brm model for 2-component composition (WAKE vs SB)", {
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("WAKE", "SB"), idvar = "ID")
+                  parts = c("WAKE", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("WAKE", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   g <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -760,11 +760,11 @@ test_that("wsub's results matches with brm model for 2-component composition (MV
   
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("MVPA", "LPA"), idvar = "ID")
+                  parts = c("MVPA", "LPA"), idvar = "ID", total = 1440)
   psub <- basesub(c("MVPA", "LPA"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   h <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -791,11 +791,11 @@ test_that("wsub's results matches with brm model for 2-component composition (MV
   
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("MVPA", "SB"), idvar = "ID")
+                  parts = c("MVPA", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("MVPA", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   i <- wsub(object = m, basesub = psub, delta = 1:2)
@@ -822,11 +822,11 @@ test_that("wsub's results matches with brm model for 2-component composition (LP
   
   sbp <- as.matrix(data.table(1, -1))
   cilr <- compilr(data = mcompd[ID %in% 1:10, .SD[1:3], by = ID], sbp = sbp,
-                  parts = c("LPA", "SB"), idvar = "ID")
+                  parts = c("LPA", "SB"), idvar = "ID", total = 1440)
   psub <- basesub(c("LPA", "SB"))
   suppressWarnings(
     m <- brmcoda(compilr = cilr,
-                 formula = STRESS ~ bilr1 + wilr1 + (1 | ID),
+                 formula = Stress ~ bilr1 + wilr1 + (1 | ID),
                  chain = 1, iter = 500, seed = 123,
                  backend = backend))
   j <- wsub(object = m, basesub = psub, delta = 1:2)
